from typing import Any, Dict, List, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.extract_task_out import ExtractTaskOut
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    name: Union[Unset, str] = "",
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Dict[str, Any]:
    url = "{}/api/v1/extract/tasks/".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "name": name,
        "limit": limit,
        "offset": offset,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[List[ExtractTaskOut], None, None, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = ExtractTaskOut.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[List[ExtractTaskOut], None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    name: Union[Unset, str] = "",
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Response[Union[List[ExtractTaskOut], None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        name=name,
        limit=limit,
        offset=offset,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    name: Union[Unset, str] = "",
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Optional[Union[List[ExtractTaskOut], None, None, HTTPValidationError]]:
    """List the organization's extract tasks.

    Only orgadmins are allowed to access extract tasks.
    The organization's id is guessed from the session token.

    Tasks can be filtered by name.

    This route returns:
    - All of the organization's complete tasks
    - Ongoing tasks that the connected user has run (a user cannot see other users ongoing tasks)"""

    return sync_detailed(
        client=client,
        name=name,
        limit=limit,
        offset=offset,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    name: Union[Unset, str] = "",
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Response[Union[List[ExtractTaskOut], None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        name=name,
        limit=limit,
        offset=offset,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    name: Union[Unset, str] = "",
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Optional[Union[List[ExtractTaskOut], None, None, HTTPValidationError]]:
    """List the organization's extract tasks.

    Only orgadmins are allowed to access extract tasks.
    The organization's id is guessed from the session token.

    Tasks can be filtered by name.

    This route returns:
    - All of the organization's complete tasks
    - Ongoing tasks that the connected user has run (a user cannot see other users ongoing tasks)"""

    return (
        await asyncio_detailed(
            client=client,
            name=name,
            limit=limit,
            offset=offset,
        )
    ).parsed



from enum import Enum


class Timezone(str, Enum):
    AFRICAABIDJAN = "Africa/Abidjan"
    AFRICAACCRA = "Africa/Accra"
    AFRICAADDIS_ABABA = "Africa/Addis_Ababa"
    AFRICAALGIERS = "Africa/Algiers"
    AFRICAASMARA = "Africa/Asmara"
    AFRICAASMERA = "Africa/Asmera"
    AFRICABAMAKO = "Africa/Bamako"
    AFRICABANGUI = "Africa/Bangui"
    AFRICABANJUL = "Africa/Banjul"
    AFRICABISSAU = "Africa/Bissau"
    AFRICABLANTYRE = "Africa/Blantyre"
    AFRICABRAZZAVILLE = "Africa/Brazzaville"
    AFRICABUJUMBURA = "Africa/Bujumbura"
    AFRICACAIRO = "Africa/Cairo"
    AFRICACASABLANCA = "Africa/Casablanca"
    AFRICACEUTA = "Africa/Ceuta"
    AFRICACONAKRY = "Africa/Conakry"
    AFRICADAKAR = "Africa/Dakar"
    AFRICADAR_ES_SALAAM = "Africa/Dar_es_Salaam"
    AFRICADJIBOUTI = "Africa/Djibouti"
    AFRICADOUALA = "Africa/Douala"
    AFRICAEL_AAIUN = "Africa/El_Aaiun"
    AFRICAFREETOWN = "Africa/Freetown"
    AFRICAGABORONE = "Africa/Gaborone"
    AFRICAHARARE = "Africa/Harare"
    AFRICAJOHANNESBURG = "Africa/Johannesburg"
    AFRICAJUBA = "Africa/Juba"
    AFRICAKAMPALA = "Africa/Kampala"
    AFRICAKHARTOUM = "Africa/Khartoum"
    AFRICAKIGALI = "Africa/Kigali"
    AFRICAKINSHASA = "Africa/Kinshasa"
    AFRICALAGOS = "Africa/Lagos"
    AFRICALIBREVILLE = "Africa/Libreville"
    AFRICALOME = "Africa/Lome"
    AFRICALUANDA = "Africa/Luanda"
    AFRICALUBUMBASHI = "Africa/Lubumbashi"
    AFRICALUSAKA = "Africa/Lusaka"
    AFRICAMALABO = "Africa/Malabo"
    AFRICAMAPUTO = "Africa/Maputo"
    AFRICAMASERU = "Africa/Maseru"
    AFRICAMBABANE = "Africa/Mbabane"
    AFRICAMOGADISHU = "Africa/Mogadishu"
    AFRICAMONROVIA = "Africa/Monrovia"
    AFRICANAIROBI = "Africa/Nairobi"
    AFRICANDJAMENA = "Africa/Ndjamena"
    AFRICANIAMEY = "Africa/Niamey"
    AFRICANOUAKCHOTT = "Africa/Nouakchott"
    AFRICAOUAGADOUGOU = "Africa/Ouagadougou"
    AFRICAPORTO_NOVO = "Africa/Porto-Novo"
    AFRICASAO_TOME = "Africa/Sao_Tome"
    AFRICATIMBUKTU = "Africa/Timbuktu"
    AFRICATRIPOLI = "Africa/Tripoli"
    AFRICATUNIS = "Africa/Tunis"
    AFRICAWINDHOEK = "Africa/Windhoek"
    AMERICAADAK = "America/Adak"
    AMERICAANCHORAGE = "America/Anchorage"
    AMERICAANGUILLA = "America/Anguilla"
    AMERICAANTIGUA = "America/Antigua"
    AMERICAARAGUAINA = "America/Araguaina"
    AMERICAARGENTINABUENOS_AIRES = "America/Argentina/Buenos_Aires"
    AMERICAARGENTINACATAMARCA = "America/Argentina/Catamarca"
    AMERICAARGENTINACOMODRIVADAVIA = "America/Argentina/ComodRivadavia"
    AMERICAARGENTINACORDOBA = "America/Argentina/Cordoba"
    AMERICAARGENTINAJUJUY = "America/Argentina/Jujuy"
    AMERICAARGENTINALA_RIOJA = "America/Argentina/La_Rioja"
    AMERICAARGENTINAMENDOZA = "America/Argentina/Mendoza"
    AMERICAARGENTINARIO_GALLEGOS = "America/Argentina/Rio_Gallegos"
    AMERICAARGENTINASALTA = "America/Argentina/Salta"
    AMERICAARGENTINASAN_JUAN = "America/Argentina/San_Juan"
    AMERICAARGENTINASAN_LUIS = "America/Argentina/San_Luis"
    AMERICAARGENTINATUCUMAN = "America/Argentina/Tucuman"
    AMERICAARGENTINAUSHUAIA = "America/Argentina/Ushuaia"
    AMERICAARUBA = "America/Aruba"
    AMERICAASUNCION = "America/Asuncion"
    AMERICAATIKOKAN = "America/Atikokan"
    AMERICAATKA = "America/Atka"
    AMERICABAHIA = "America/Bahia"
    AMERICABAHIA_BANDERAS = "America/Bahia_Banderas"
    AMERICABARBADOS = "America/Barbados"
    AMERICABELEM = "America/Belem"
    AMERICABELIZE = "America/Belize"
    AMERICABLANC_SABLON = "America/Blanc-Sablon"
    AMERICABOA_VISTA = "America/Boa_Vista"
    AMERICABOGOTA = "America/Bogota"
    AMERICABOISE = "America/Boise"
    AMERICABUENOS_AIRES = "America/Buenos_Aires"
    AMERICACAMBRIDGE_BAY = "America/Cambridge_Bay"
    AMERICACAMPO_GRANDE = "America/Campo_Grande"
    AMERICACANCUN = "America/Cancun"
    AMERICACARACAS = "America/Caracas"
    AMERICACATAMARCA = "America/Catamarca"
    AMERICACAYENNE = "America/Cayenne"
    AMERICACAYMAN = "America/Cayman"
    AMERICACHICAGO = "America/Chicago"
    AMERICACHIHUAHUA = "America/Chihuahua"
    AMERICACORAL_HARBOUR = "America/Coral_Harbour"
    AMERICACORDOBA = "America/Cordoba"
    AMERICACOSTA_RICA = "America/Costa_Rica"
    AMERICACRESTON = "America/Creston"
    AMERICACUIABA = "America/Cuiaba"
    AMERICACURACAO = "America/Curacao"
    AMERICADANMARKSHAVN = "America/Danmarkshavn"
    AMERICADAWSON = "America/Dawson"
    AMERICADAWSON_CREEK = "America/Dawson_Creek"
    AMERICADENVER = "America/Denver"
    AMERICADETROIT = "America/Detroit"
    AMERICADOMINICA = "America/Dominica"
    AMERICAEDMONTON = "America/Edmonton"
    AMERICAEIRUNEPE = "America/Eirunepe"
    AMERICAEL_SALVADOR = "America/El_Salvador"
    AMERICAENSENADA = "America/Ensenada"
    AMERICAFORT_NELSON = "America/Fort_Nelson"
    AMERICAFORT_WAYNE = "America/Fort_Wayne"
    AMERICAFORTALEZA = "America/Fortaleza"
    AMERICAGLACE_BAY = "America/Glace_Bay"
    AMERICAGODTHAB = "America/Godthab"
    AMERICAGOOSE_BAY = "America/Goose_Bay"
    AMERICAGRAND_TURK = "America/Grand_Turk"
    AMERICAGRENADA = "America/Grenada"
    AMERICAGUADELOUPE = "America/Guadeloupe"
    AMERICAGUATEMALA = "America/Guatemala"
    AMERICAGUAYAQUIL = "America/Guayaquil"
    AMERICAGUYANA = "America/Guyana"
    AMERICAHALIFAX = "America/Halifax"
    AMERICAHAVANA = "America/Havana"
    AMERICAHERMOSILLO = "America/Hermosillo"
    AMERICAINDIANAINDIANAPOLIS = "America/Indiana/Indianapolis"
    AMERICAINDIANAKNOX = "America/Indiana/Knox"
    AMERICAINDIANAMARENGO = "America/Indiana/Marengo"
    AMERICAINDIANAPETERSBURG = "America/Indiana/Petersburg"
    AMERICAINDIANATELL_CITY = "America/Indiana/Tell_City"
    AMERICAINDIANAVEVAY = "America/Indiana/Vevay"
    AMERICAINDIANAVINCENNES = "America/Indiana/Vincennes"
    AMERICAINDIANAWINAMAC = "America/Indiana/Winamac"
    AMERICAINDIANAPOLIS = "America/Indianapolis"
    AMERICAINUVIK = "America/Inuvik"
    AMERICAIQALUIT = "America/Iqaluit"
    AMERICAJAMAICA = "America/Jamaica"
    AMERICAJUJUY = "America/Jujuy"
    AMERICAJUNEAU = "America/Juneau"
    AMERICAKENTUCKYLOUISVILLE = "America/Kentucky/Louisville"
    AMERICAKENTUCKYMONTICELLO = "America/Kentucky/Monticello"
    AMERICAKNOX_IN = "America/Knox_IN"
    AMERICAKRALENDIJK = "America/Kralendijk"
    AMERICALA_PAZ = "America/La_Paz"
    AMERICALIMA = "America/Lima"
    AMERICALOS_ANGELES = "America/Los_Angeles"
    AMERICALOUISVILLE = "America/Louisville"
    AMERICALOWER_PRINCES = "America/Lower_Princes"
    AMERICAMACEIO = "America/Maceio"
    AMERICAMANAGUA = "America/Managua"
    AMERICAMANAUS = "America/Manaus"
    AMERICAMARIGOT = "America/Marigot"
    AMERICAMARTINIQUE = "America/Martinique"
    AMERICAMATAMOROS = "America/Matamoros"
    AMERICAMAZATLAN = "America/Mazatlan"
    AMERICAMENDOZA = "America/Mendoza"
    AMERICAMENOMINEE = "America/Menominee"
    AMERICAMERIDA = "America/Merida"
    AMERICAMETLAKATLA = "America/Metlakatla"
    AMERICAMEXICO_CITY = "America/Mexico_City"
    AMERICAMIQUELON = "America/Miquelon"
    AMERICAMONCTON = "America/Moncton"
    AMERICAMONTERREY = "America/Monterrey"
    AMERICAMONTEVIDEO = "America/Montevideo"
    AMERICAMONTREAL = "America/Montreal"
    AMERICAMONTSERRAT = "America/Montserrat"
    AMERICANASSAU = "America/Nassau"
    AMERICANEW_YORK = "America/New_York"
    AMERICANIPIGON = "America/Nipigon"
    AMERICANOME = "America/Nome"
    AMERICANORONHA = "America/Noronha"
    AMERICANORTH_DAKOTABEULAH = "America/North_Dakota/Beulah"
    AMERICANORTH_DAKOTACENTER = "America/North_Dakota/Center"
    AMERICANORTH_DAKOTANEW_SALEM = "America/North_Dakota/New_Salem"
    AMERICANUUK = "America/Nuuk"
    AMERICAOJINAGA = "America/Ojinaga"
    AMERICAPANAMA = "America/Panama"
    AMERICAPANGNIRTUNG = "America/Pangnirtung"
    AMERICAPARAMARIBO = "America/Paramaribo"
    AMERICAPHOENIX = "America/Phoenix"
    AMERICAPORT_AU_PRINCE = "America/Port-au-Prince"
    AMERICAPORT_OF_SPAIN = "America/Port_of_Spain"
    AMERICAPORTO_ACRE = "America/Porto_Acre"
    AMERICAPORTO_VELHO = "America/Porto_Velho"
    AMERICAPUERTO_RICO = "America/Puerto_Rico"
    AMERICAPUNTA_ARENAS = "America/Punta_Arenas"
    AMERICARAINY_RIVER = "America/Rainy_River"
    AMERICARANKIN_INLET = "America/Rankin_Inlet"
    AMERICARECIFE = "America/Recife"
    AMERICAREGINA = "America/Regina"
    AMERICARESOLUTE = "America/Resolute"
    AMERICARIO_BRANCO = "America/Rio_Branco"
    AMERICAROSARIO = "America/Rosario"
    AMERICASANTA_ISABEL = "America/Santa_Isabel"
    AMERICASANTAREM = "America/Santarem"
    AMERICASANTIAGO = "America/Santiago"
    AMERICASANTO_DOMINGO = "America/Santo_Domingo"
    AMERICASAO_PAULO = "America/Sao_Paulo"
    AMERICASCORESBYSUND = "America/Scoresbysund"
    AMERICASHIPROCK = "America/Shiprock"
    AMERICASITKA = "America/Sitka"
    AMERICAST_BARTHELEMY = "America/St_Barthelemy"
    AMERICAST_JOHNS = "America/St_Johns"
    AMERICAST_KITTS = "America/St_Kitts"
    AMERICAST_LUCIA = "America/St_Lucia"
    AMERICAST_THOMAS = "America/St_Thomas"
    AMERICAST_VINCENT = "America/St_Vincent"
    AMERICASWIFT_CURRENT = "America/Swift_Current"
    AMERICATEGUCIGALPA = "America/Tegucigalpa"
    AMERICATHULE = "America/Thule"
    AMERICATHUNDER_BAY = "America/Thunder_Bay"
    AMERICATIJUANA = "America/Tijuana"
    AMERICATORONTO = "America/Toronto"
    AMERICATORTOLA = "America/Tortola"
    AMERICAVANCOUVER = "America/Vancouver"
    AMERICAVIRGIN = "America/Virgin"
    AMERICAWHITEHORSE = "America/Whitehorse"
    AMERICAWINNIPEG = "America/Winnipeg"
    AMERICAYAKUTAT = "America/Yakutat"
    AMERICAYELLOWKNIFE = "America/Yellowknife"
    ANTARCTICACASEY = "Antarctica/Casey"
    ANTARCTICADAVIS = "Antarctica/Davis"
    ANTARCTICADUMONTDURVILLE = "Antarctica/DumontDUrville"
    ANTARCTICAMACQUARIE = "Antarctica/Macquarie"
    ANTARCTICAMAWSON = "Antarctica/Mawson"
    ANTARCTICAMCMURDO = "Antarctica/McMurdo"
    ANTARCTICAPALMER = "Antarctica/Palmer"
    ANTARCTICAROTHERA = "Antarctica/Rothera"
    ANTARCTICASOUTH_POLE = "Antarctica/South_Pole"
    ANTARCTICASYOWA = "Antarctica/Syowa"
    ANTARCTICATROLL = "Antarctica/Troll"
    ANTARCTICAVOSTOK = "Antarctica/Vostok"
    ARCTICLONGYEARBYEN = "Arctic/Longyearbyen"
    ASIAADEN = "Asia/Aden"
    ASIAALMATY = "Asia/Almaty"
    ASIAAMMAN = "Asia/Amman"
    ASIAANADYR = "Asia/Anadyr"
    ASIAAQTAU = "Asia/Aqtau"
    ASIAAQTOBE = "Asia/Aqtobe"
    ASIAASHGABAT = "Asia/Ashgabat"
    ASIAASHKHABAD = "Asia/Ashkhabad"
    ASIAATYRAU = "Asia/Atyrau"
    ASIABAGHDAD = "Asia/Baghdad"
    ASIABAHRAIN = "Asia/Bahrain"
    ASIABAKU = "Asia/Baku"
    ASIABANGKOK = "Asia/Bangkok"
    ASIABARNAUL = "Asia/Barnaul"
    ASIABEIRUT = "Asia/Beirut"
    ASIABISHKEK = "Asia/Bishkek"
    ASIABRUNEI = "Asia/Brunei"
    ASIACALCUTTA = "Asia/Calcutta"
    ASIACHITA = "Asia/Chita"
    ASIACHOIBALSAN = "Asia/Choibalsan"
    ASIACHONGQING = "Asia/Chongqing"
    ASIACHUNGKING = "Asia/Chungking"
    ASIACOLOMBO = "Asia/Colombo"
    ASIADACCA = "Asia/Dacca"
    ASIADAMASCUS = "Asia/Damascus"
    ASIADHAKA = "Asia/Dhaka"
    ASIADILI = "Asia/Dili"
    ASIADUBAI = "Asia/Dubai"
    ASIADUSHANBE = "Asia/Dushanbe"
    ASIAFAMAGUSTA = "Asia/Famagusta"
    ASIAGAZA = "Asia/Gaza"
    ASIAHARBIN = "Asia/Harbin"
    ASIAHEBRON = "Asia/Hebron"
    ASIAHO_CHI_MINH = "Asia/Ho_Chi_Minh"
    ASIAHONG_KONG = "Asia/Hong_Kong"
    ASIAHOVD = "Asia/Hovd"
    ASIAIRKUTSK = "Asia/Irkutsk"
    ASIAISTANBUL = "Asia/Istanbul"
    ASIAJAKARTA = "Asia/Jakarta"
    ASIAJAYAPURA = "Asia/Jayapura"
    ASIAJERUSALEM = "Asia/Jerusalem"
    ASIAKABUL = "Asia/Kabul"
    ASIAKAMCHATKA = "Asia/Kamchatka"
    ASIAKARACHI = "Asia/Karachi"
    ASIAKASHGAR = "Asia/Kashgar"
    ASIAKATHMANDU = "Asia/Kathmandu"
    ASIAKATMANDU = "Asia/Katmandu"
    ASIAKHANDYGA = "Asia/Khandyga"
    ASIAKOLKATA = "Asia/Kolkata"
    ASIAKRASNOYARSK = "Asia/Krasnoyarsk"
    ASIAKUALA_LUMPUR = "Asia/Kuala_Lumpur"
    ASIAKUCHING = "Asia/Kuching"
    ASIAKUWAIT = "Asia/Kuwait"
    ASIAMACAO = "Asia/Macao"
    ASIAMACAU = "Asia/Macau"
    ASIAMAGADAN = "Asia/Magadan"
    ASIAMAKASSAR = "Asia/Makassar"
    ASIAMANILA = "Asia/Manila"
    ASIAMUSCAT = "Asia/Muscat"
    ASIANICOSIA = "Asia/Nicosia"
    ASIANOVOKUZNETSK = "Asia/Novokuznetsk"
    ASIANOVOSIBIRSK = "Asia/Novosibirsk"
    ASIAOMSK = "Asia/Omsk"
    ASIAORAL = "Asia/Oral"
    ASIAPHNOM_PENH = "Asia/Phnom_Penh"
    ASIAPONTIANAK = "Asia/Pontianak"
    ASIAPYONGYANG = "Asia/Pyongyang"
    ASIAQATAR = "Asia/Qatar"
    ASIAQOSTANAY = "Asia/Qostanay"
    ASIAQYZYLORDA = "Asia/Qyzylorda"
    ASIARANGOON = "Asia/Rangoon"
    ASIARIYADH = "Asia/Riyadh"
    ASIASAIGON = "Asia/Saigon"
    ASIASAKHALIN = "Asia/Sakhalin"
    ASIASAMARKAND = "Asia/Samarkand"
    ASIASEOUL = "Asia/Seoul"
    ASIASHANGHAI = "Asia/Shanghai"
    ASIASINGAPORE = "Asia/Singapore"
    ASIASREDNEKOLYMSK = "Asia/Srednekolymsk"
    ASIATAIPEI = "Asia/Taipei"
    ASIATASHKENT = "Asia/Tashkent"
    ASIATBILISI = "Asia/Tbilisi"
    ASIATEHRAN = "Asia/Tehran"
    ASIATEL_AVIV = "Asia/Tel_Aviv"
    ASIATHIMBU = "Asia/Thimbu"
    ASIATHIMPHU = "Asia/Thimphu"
    ASIATOKYO = "Asia/Tokyo"
    ASIATOMSK = "Asia/Tomsk"
    ASIAUJUNG_PANDANG = "Asia/Ujung_Pandang"
    ASIAULAANBAATAR = "Asia/Ulaanbaatar"
    ASIAULAN_BATOR = "Asia/Ulan_Bator"
    ASIAURUMQI = "Asia/Urumqi"
    ASIAUST_NERA = "Asia/Ust-Nera"
    ASIAVIENTIANE = "Asia/Vientiane"
    ASIAVLADIVOSTOK = "Asia/Vladivostok"
    ASIAYAKUTSK = "Asia/Yakutsk"
    ASIAYANGON = "Asia/Yangon"
    ASIAYEKATERINBURG = "Asia/Yekaterinburg"
    ASIAYEREVAN = "Asia/Yerevan"
    ATLANTICAZORES = "Atlantic/Azores"
    ATLANTICBERMUDA = "Atlantic/Bermuda"
    ATLANTICCANARY = "Atlantic/Canary"
    ATLANTICCAPE_VERDE = "Atlantic/Cape_Verde"
    ATLANTICFAEROE = "Atlantic/Faeroe"
    ATLANTICFAROE = "Atlantic/Faroe"
    ATLANTICJAN_MAYEN = "Atlantic/Jan_Mayen"
    ATLANTICMADEIRA = "Atlantic/Madeira"
    ATLANTICREYKJAVIK = "Atlantic/Reykjavik"
    ATLANTICSOUTH_GEORGIA = "Atlantic/South_Georgia"
    ATLANTICST_HELENA = "Atlantic/St_Helena"
    ATLANTICSTANLEY = "Atlantic/Stanley"
    AUSTRALIAACT = "Australia/ACT"
    AUSTRALIAADELAIDE = "Australia/Adelaide"
    AUSTRALIABRISBANE = "Australia/Brisbane"
    AUSTRALIABROKEN_HILL = "Australia/Broken_Hill"
    AUSTRALIACANBERRA = "Australia/Canberra"
    AUSTRALIACURRIE = "Australia/Currie"
    AUSTRALIADARWIN = "Australia/Darwin"
    AUSTRALIAEUCLA = "Australia/Eucla"
    AUSTRALIAHOBART = "Australia/Hobart"
    AUSTRALIALHI = "Australia/LHI"
    AUSTRALIALINDEMAN = "Australia/Lindeman"
    AUSTRALIALORD_HOWE = "Australia/Lord_Howe"
    AUSTRALIAMELBOURNE = "Australia/Melbourne"
    AUSTRALIANSW = "Australia/NSW"
    AUSTRALIANORTH = "Australia/North"
    AUSTRALIAPERTH = "Australia/Perth"
    AUSTRALIAQUEENSLAND = "Australia/Queensland"
    AUSTRALIASOUTH = "Australia/South"
    AUSTRALIASYDNEY = "Australia/Sydney"
    AUSTRALIATASMANIA = "Australia/Tasmania"
    AUSTRALIAVICTORIA = "Australia/Victoria"
    AUSTRALIAWEST = "Australia/West"
    AUSTRALIAYANCOWINNA = "Australia/Yancowinna"
    BRAZILACRE = "Brazil/Acre"
    BRAZILDENORONHA = "Brazil/DeNoronha"
    BRAZILEAST = "Brazil/East"
    BRAZILWEST = "Brazil/West"
    CET = "CET"
    C_S_T6_CDT = "CST6CDT"
    CANADAATLANTIC = "Canada/Atlantic"
    CANADACENTRAL = "Canada/Central"
    CANADAEASTERN = "Canada/Eastern"
    CANADAMOUNTAIN = "Canada/Mountain"
    CANADANEWFOUNDLAND = "Canada/Newfoundland"
    CANADAPACIFIC = "Canada/Pacific"
    CANADASASKATCHEWAN = "Canada/Saskatchewan"
    CANADAYUKON = "Canada/Yukon"
    CHILECONTINENTAL = "Chile/Continental"
    CHILEEASTERISLAND = "Chile/EasterIsland"
    CUBA = "Cuba"
    EET = "EET"
    EST = "EST"
    E_S_T5_EDT = "EST5EDT"
    EGYPT = "Egypt"
    EIRE = "Eire"
    E_T_C_G_M_T0 = "Etc/GMT0"
    ETCGREENWICH = "Etc/Greenwich"
    ETCUCT = "Etc/UCT"
    ETCUTC = "Etc/UTC"
    ETCUNIVERSAL = "Etc/Universal"
    ETCZULU = "Etc/Zulu"
    EUROPEAMSTERDAM = "Europe/Amsterdam"
    EUROPEANDORRA = "Europe/Andorra"
    EUROPEASTRAKHAN = "Europe/Astrakhan"
    EUROPEATHENS = "Europe/Athens"
    EUROPEBELFAST = "Europe/Belfast"
    EUROPEBELGRADE = "Europe/Belgrade"
    EUROPEBERLIN = "Europe/Berlin"
    EUROPEBRATISLAVA = "Europe/Bratislava"
    EUROPEBRUSSELS = "Europe/Brussels"
    EUROPEBUCHAREST = "Europe/Bucharest"
    EUROPEBUDAPEST = "Europe/Budapest"
    EUROPEBUSINGEN = "Europe/Busingen"
    EUROPECHISINAU = "Europe/Chisinau"
    EUROPECOPENHAGEN = "Europe/Copenhagen"
    EUROPEDUBLIN = "Europe/Dublin"
    EUROPEGIBRALTAR = "Europe/Gibraltar"
    EUROPEGUERNSEY = "Europe/Guernsey"
    EUROPEHELSINKI = "Europe/Helsinki"
    EUROPEISLE_OF_MAN = "Europe/Isle_of_Man"
    EUROPEISTANBUL = "Europe/Istanbul"
    EUROPEJERSEY = "Europe/Jersey"
    EUROPEKALININGRAD = "Europe/Kaliningrad"
    EUROPEKIEV = "Europe/Kiev"
    EUROPEKIROV = "Europe/Kirov"
    EUROPELISBON = "Europe/Lisbon"
    EUROPELJUBLJANA = "Europe/Ljubljana"
    EUROPELONDON = "Europe/London"
    EUROPELUXEMBOURG = "Europe/Luxembourg"
    EUROPEMADRID = "Europe/Madrid"
    EUROPEMALTA = "Europe/Malta"
    EUROPEMARIEHAMN = "Europe/Mariehamn"
    EUROPEMINSK = "Europe/Minsk"
    EUROPEMONACO = "Europe/Monaco"
    EUROPEMOSCOW = "Europe/Moscow"
    EUROPENICOSIA = "Europe/Nicosia"
    EUROPEOSLO = "Europe/Oslo"
    EUROPEPARIS = "Europe/Paris"
    EUROPEPODGORICA = "Europe/Podgorica"
    EUROPEPRAGUE = "Europe/Prague"
    EUROPERIGA = "Europe/Riga"
    EUROPEROME = "Europe/Rome"
    EUROPESAMARA = "Europe/Samara"
    EUROPESAN_MARINO = "Europe/San_Marino"
    EUROPESARAJEVO = "Europe/Sarajevo"
    EUROPESARATOV = "Europe/Saratov"
    EUROPESIMFEROPOL = "Europe/Simferopol"
    EUROPESKOPJE = "Europe/Skopje"
    EUROPESOFIA = "Europe/Sofia"
    EUROPESTOCKHOLM = "Europe/Stockholm"
    EUROPETALLINN = "Europe/Tallinn"
    EUROPETIRANE = "Europe/Tirane"
    EUROPETIRASPOL = "Europe/Tiraspol"
    EUROPEULYANOVSK = "Europe/Ulyanovsk"
    EUROPEUZHGOROD = "Europe/Uzhgorod"
    EUROPEVADUZ = "Europe/Vaduz"
    EUROPEVATICAN = "Europe/Vatican"
    EUROPEVIENNA = "Europe/Vienna"
    EUROPEVILNIUS = "Europe/Vilnius"
    EUROPEVOLGOGRAD = "Europe/Volgograd"
    EUROPEWARSAW = "Europe/Warsaw"
    EUROPEZAGREB = "Europe/Zagreb"
    EUROPEZAPOROZHYE = "Europe/Zaporozhye"
    EUROPEZURICH = "Europe/Zurich"
    GB = "GB"
    GB_EIRE = "GB-Eire"
    G_M_T0 = "GMT0"
    GREENWICH = "Greenwich"
    HST = "HST"
    HONGKONG = "Hongkong"
    ICELAND = "Iceland"
    INDIANANTANANARIVO = "Indian/Antananarivo"
    INDIANCHAGOS = "Indian/Chagos"
    INDIANCHRISTMAS = "Indian/Christmas"
    INDIANCOCOS = "Indian/Cocos"
    INDIANCOMORO = "Indian/Comoro"
    INDIANKERGUELEN = "Indian/Kerguelen"
    INDIANMAHE = "Indian/Mahe"
    INDIANMALDIVES = "Indian/Maldives"
    INDIANMAURITIUS = "Indian/Mauritius"
    INDIANMAYOTTE = "Indian/Mayotte"
    INDIANREUNION = "Indian/Reunion"
    IRAN = "Iran"
    ISRAEL = "Israel"
    JAMAICA = "Jamaica"
    JAPAN = "Japan"
    KWAJALEIN = "Kwajalein"
    LIBYA = "Libya"
    MET = "MET"
    MST = "MST"
    M_S_T7_MDT = "MST7MDT"
    MEXICOBAJANORTE = "Mexico/BajaNorte"
    MEXICOBAJASUR = "Mexico/BajaSur"
    MEXICOGENERAL = "Mexico/General"
    NZ = "NZ"
    NZ_CHAT = "NZ-CHAT"
    NAVAJO = "Navajo"
    PRC = "PRC"
    P_S_T8_PDT = "PST8PDT"
    PACIFICAPIA = "Pacific/Apia"
    PACIFICAUCKLAND = "Pacific/Auckland"
    PACIFICBOUGAINVILLE = "Pacific/Bougainville"
    PACIFICCHATHAM = "Pacific/Chatham"
    PACIFICCHUUK = "Pacific/Chuuk"
    PACIFICEASTER = "Pacific/Easter"
    PACIFICEFATE = "Pacific/Efate"
    PACIFICENDERBURY = "Pacific/Enderbury"
    PACIFICFAKAOFO = "Pacific/Fakaofo"
    PACIFICFIJI = "Pacific/Fiji"
    PACIFICFUNAFUTI = "Pacific/Funafuti"
    PACIFICGALAPAGOS = "Pacific/Galapagos"
    PACIFICGAMBIER = "Pacific/Gambier"
    PACIFICGUADALCANAL = "Pacific/Guadalcanal"
    PACIFICGUAM = "Pacific/Guam"
    PACIFICHONOLULU = "Pacific/Honolulu"
    PACIFICJOHNSTON = "Pacific/Johnston"
    PACIFICKIRITIMATI = "Pacific/Kiritimati"
    PACIFICKOSRAE = "Pacific/Kosrae"
    PACIFICKWAJALEIN = "Pacific/Kwajalein"
    PACIFICMAJURO = "Pacific/Majuro"
    PACIFICMARQUESAS = "Pacific/Marquesas"
    PACIFICMIDWAY = "Pacific/Midway"
    PACIFICNAURU = "Pacific/Nauru"
    PACIFICNIUE = "Pacific/Niue"
    PACIFICNORFOLK = "Pacific/Norfolk"
    PACIFICNOUMEA = "Pacific/Noumea"
    PACIFICPAGO_PAGO = "Pacific/Pago_Pago"
    PACIFICPALAU = "Pacific/Palau"
    PACIFICPITCAIRN = "Pacific/Pitcairn"
    PACIFICPOHNPEI = "Pacific/Pohnpei"
    PACIFICPONAPE = "Pacific/Ponape"
    PACIFICPORT_MORESBY = "Pacific/Port_Moresby"
    PACIFICRAROTONGA = "Pacific/Rarotonga"
    PACIFICSAIPAN = "Pacific/Saipan"
    PACIFICSAMOA = "Pacific/Samoa"
    PACIFICTAHITI = "Pacific/Tahiti"
    PACIFICTARAWA = "Pacific/Tarawa"
    PACIFICTONGATAPU = "Pacific/Tongatapu"
    PACIFICTRUK = "Pacific/Truk"
    PACIFICWAKE = "Pacific/Wake"
    PACIFICWALLIS = "Pacific/Wallis"
    PACIFICYAP = "Pacific/Yap"
    POLAND = "Poland"
    PORTUGAL = "Portugal"
    ROC = "ROC"
    ROK = "ROK"
    SINGAPORE = "Singapore"
    TURKEY = "Turkey"
    UCT = "UCT"
    USALASKA = "US/Alaska"
    USALEUTIAN = "US/Aleutian"
    USARIZONA = "US/Arizona"
    USCENTRAL = "US/Central"
    USEAST_INDIANA = "US/East-Indiana"
    USEASTERN = "US/Eastern"
    USHAWAII = "US/Hawaii"
    USINDIANA_STARKE = "US/Indiana-Starke"
    USMICHIGAN = "US/Michigan"
    USMOUNTAIN = "US/Mountain"
    USPACIFIC = "US/Pacific"
    USSAMOA = "US/Samoa"
    UTC = "UTC"
    UNIVERSAL = "Universal"
    W_SU = "W-SU"
    WET = "WET"
    ZULU = "Zulu"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="EmailTemplateOut")


@attr.s(auto_attribs=True)
class EmailTemplateOut:
    """ Email Template schema for endpoints return. """

    display_name: str
    id: int
    internal_name: str
    subject: str
    body: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        display_name = self.display_name
        id = self.id
        internal_name = self.internal_name
        subject = self.subject
        body = self.body

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "display_name": display_name,
                "id": id,
                "internal_name": internal_name,
                "subject": subject,
                "body": body,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        display_name = d.pop("display_name")

        id = d.pop("id")

        internal_name = d.pop("internal_name")

        subject = d.pop("subject")

        body = d.pop("body")

        email_template_out = cls(
            display_name=display_name,
            id=id,
            internal_name=internal_name,
            subject=subject,
            body=body,
        )

        email_template_out.additional_properties = d
        return email_template_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.background_task_update_status import BackgroundTaskUpdateStatus
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    task_id: int,
    json_body: BackgroundTaskUpdateStatus,
) -> Dict[str, Any]:
    url = "{}/api/v1/tasks/{task_id}/status/".format(client.base_url, task_id=task_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[None, None, None, None, HTTPValidationError]]:
    if response.status_code == 204:
        response_204 = None

        return response_204
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[None, None, None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    task_id: int,
    json_body: BackgroundTaskUpdateStatus,
) -> Response[Union[None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        task_id=task_id,
        json_body=json_body,
    )

    response = httpx.put(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    task_id: int,
    json_body: BackgroundTaskUpdateStatus,
) -> Optional[Union[None, None, None, None, HTTPValidationError]]:
    """Updates the status of a background task.

    This route allows to change the number of items
    to be processed and the task status.

    Only services are allowed to update tasks status."""

    return sync_detailed(
        client=client,
        task_id=task_id,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    task_id: int,
    json_body: BackgroundTaskUpdateStatus,
) -> Response[Union[None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        task_id=task_id,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.put(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    task_id: int,
    json_body: BackgroundTaskUpdateStatus,
) -> Optional[Union[None, None, None, None, HTTPValidationError]]:
    """Updates the status of a background task.

    This route allows to change the number of items
    to be processed and the task status.

    Only services are allowed to update tasks status."""

    return (
        await asyncio_detailed(
            client=client,
            task_id=task_id,
            json_body=json_body,
        )
    ).parsed



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.group_out import GroupOut

T = TypeVar("T", bound="ContentDetailsOut")


@attr.s(auto_attribs=True)
class ContentDetailsOut:
    """ Content details schema to output from GET method. """

    id: int
    name: str
    groups: List[GroupOut]
    total_folders: int
    total_files: int
    total_size: int
    num_defined_metadata: int
    num_indexed_files: int
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        name = self.name
        groups = []
        for groups_item_data in self.groups:
            groups_item = groups_item_data.to_dict()

            groups.append(groups_item)

        total_folders = self.total_folders
        total_files = self.total_files
        total_size = self.total_size
        num_defined_metadata = self.num_defined_metadata
        num_indexed_files = self.num_indexed_files

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "name": name,
                "groups": groups,
                "total_folders": total_folders,
                "total_files": total_files,
                "total_size": total_size,
                "num_defined_metadata": num_defined_metadata,
                "num_indexed_files": num_indexed_files,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        name = d.pop("name")

        groups = []
        _groups = d.pop("groups")
        for groups_item_data in _groups:
            groups_item = GroupOut.from_dict(groups_item_data)

            groups.append(groups_item)

        total_folders = d.pop("total_folders")

        total_files = d.pop("total_files")

        total_size = d.pop("total_size")

        num_defined_metadata = d.pop("num_defined_metadata")

        num_indexed_files = d.pop("num_indexed_files")

        content_details_out = cls(
            id=id,
            name=name,
            groups=groups,
            total_folders=total_folders,
            total_files=total_files,
            total_size=total_size,
            num_defined_metadata=num_defined_metadata,
            num_indexed_files=num_indexed_files,
        )

        content_details_out.additional_properties = d
        return content_details_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.search_query_keywords import SearchQueryKeywords

T = TypeVar("T", bound="DocSearchMetadata")


@attr.s(auto_attribs=True)
class DocSearchMetadata:
    """ Input schema for metadata assignment in document results. """

    query: SearchQueryKeywords
    metadata_name: str
    metadata_value: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        query = self.query.to_dict()

        metadata_name = self.metadata_name
        metadata_value = self.metadata_value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "query": query,
                "metadata_name": metadata_name,
                "metadata_value": metadata_value,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        query = SearchQueryKeywords.from_dict(d.pop("query"))

        metadata_name = d.pop("metadata_name")

        metadata_value = d.pop("metadata_value")

        doc_search_metadata = cls(
            query=query,
            metadata_name=metadata_name,
            metadata_value=metadata_value,
        )

        doc_search_metadata.additional_properties = d
        return doc_search_metadata

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.analyzer_language import AnalyzerLanguage
from ..types import UNSET, Unset

T = TypeVar("T", bound="SearchConfigurationUpdate")


@attr.s(auto_attribs=True)
class SearchConfigurationUpdate:
    """ Search Configuration update schema. """

    auto_semantic: Union[Unset, bool] = UNSET
    manual_weight: Union[Unset, float] = UNSET
    lemma_language: Union[Unset, AnalyzerLanguage] = UNSET
    stop_words_language: Union[Unset, AnalyzerLanguage] = UNSET
    skip_neural: Union[Unset, bool] = UNSET
    metadata_boost: Union[Unset, bool] = UNSET
    auto_suggest: Union[Unset, bool] = UNSET
    lemmatization: Union[Unset, bool] = UNSET
    stop_words: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        auto_semantic = self.auto_semantic
        manual_weight = self.manual_weight
        lemma_language: Union[Unset, AnalyzerLanguage] = UNSET
        if not isinstance(self.lemma_language, Unset):
            lemma_language = self.lemma_language

        stop_words_language: Union[Unset, AnalyzerLanguage] = UNSET
        if not isinstance(self.stop_words_language, Unset):
            stop_words_language = self.stop_words_language

        skip_neural = self.skip_neural
        metadata_boost = self.metadata_boost
        auto_suggest = self.auto_suggest
        lemmatization = self.lemmatization
        stop_words = self.stop_words

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if auto_semantic is not UNSET:
            field_dict["auto_semantic"] = auto_semantic
        if manual_weight is not UNSET:
            field_dict["manual_weight"] = manual_weight
        if lemma_language is not UNSET:
            field_dict["lemma_language"] = lemma_language
        if stop_words_language is not UNSET:
            field_dict["stop_words_language"] = stop_words_language
        if skip_neural is not UNSET:
            field_dict["skip_neural"] = skip_neural
        if metadata_boost is not UNSET:
            field_dict["metadata_boost"] = metadata_boost
        if auto_suggest is not UNSET:
            field_dict["auto_suggest"] = auto_suggest
        if lemmatization is not UNSET:
            field_dict["lemmatization"] = lemmatization
        if stop_words is not UNSET:
            field_dict["stop_words"] = stop_words

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        auto_semantic = d.pop("auto_semantic", UNSET)

        manual_weight = d.pop("manual_weight", UNSET)

        lemma_language: Union[Unset, AnalyzerLanguage] = UNSET
        _lemma_language = d.pop("lemma_language", UNSET)
        if not isinstance(_lemma_language, Unset):
            lemma_language = AnalyzerLanguage(_lemma_language)

        stop_words_language: Union[Unset, AnalyzerLanguage] = UNSET
        _stop_words_language = d.pop("stop_words_language", UNSET)
        if not isinstance(_stop_words_language, Unset):
            stop_words_language = AnalyzerLanguage(_stop_words_language)

        skip_neural = d.pop("skip_neural", UNSET)

        metadata_boost = d.pop("metadata_boost", UNSET)

        auto_suggest = d.pop("auto_suggest", UNSET)

        lemmatization = d.pop("lemmatization", UNSET)

        stop_words = d.pop("stop_words", UNSET)

        search_configuration_update = cls(
            auto_semantic=auto_semantic,
            manual_weight=manual_weight,
            lemma_language=lemma_language,
            stop_words_language=stop_words_language,
            skip_neural=skip_neural,
            metadata_boost=metadata_boost,
            auto_suggest=auto_suggest,
            lemmatization=lemmatization,
            stop_words=stop_words,
        )

        search_configuration_update.additional_properties = d
        return search_configuration_update

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.extract_result_validate_out_metadata import ExtractResultValidateOutMetadata
from ..models.extract_result_validate_out_version_metadata import ExtractResultValidateOutVersionMetadata
from ..models.extract_top_chunk_validate_out import ExtractTopChunkValidateOut
from ..types import UNSET, Unset

T = TypeVar("T", bound="ExtractResultValidateOut")


@attr.s(auto_attribs=True)
class ExtractResultValidateOut:
    """ Extract result schema for validation with page HTMLs. """

    task_id: int
    doc_id: int
    doc_filename: str
    doc_path: str
    id: int
    metadata: ExtractResultValidateOutMetadata
    top_chunks: List[ExtractTopChunkValidateOut]
    validated_by: Union[Unset, str] = UNSET
    validated_on: Union[Unset, datetime.datetime] = UNSET
    status: Union[Unset, str] = UNSET
    found: Union[Unset, bool] = UNSET
    chunk_id: Union[Unset, str] = UNSET
    text: Union[Unset, str] = UNSET
    outdated: Union[Unset, bool] = UNSET
    version_metadata: Union[ExtractResultValidateOutVersionMetadata, Unset] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        task_id = self.task_id
        doc_id = self.doc_id
        doc_filename = self.doc_filename
        doc_path = self.doc_path
        id = self.id
        metadata = self.metadata.to_dict()

        top_chunks = []
        for top_chunks_item_data in self.top_chunks:
            top_chunks_item = top_chunks_item_data.to_dict()

            top_chunks.append(top_chunks_item)

        validated_by = self.validated_by
        validated_on: Union[Unset, str] = UNSET
        if not isinstance(self.validated_on, Unset):
            validated_on = self.validated_on.isoformat()

        status = self.status
        found = self.found
        chunk_id = self.chunk_id
        text = self.text
        outdated = self.outdated
        version_metadata: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.version_metadata, Unset):
            version_metadata = self.version_metadata.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "task_id": task_id,
                "doc_id": doc_id,
                "doc_filename": doc_filename,
                "doc_path": doc_path,
                "id": id,
                "metadata": metadata,
                "top_chunks": top_chunks,
            }
        )
        if validated_by is not UNSET:
            field_dict["validated_by"] = validated_by
        if validated_on is not UNSET:
            field_dict["validated_on"] = validated_on
        if status is not UNSET:
            field_dict["status"] = status
        if found is not UNSET:
            field_dict["found"] = found
        if chunk_id is not UNSET:
            field_dict["chunk_id"] = chunk_id
        if text is not UNSET:
            field_dict["text"] = text
        if outdated is not UNSET:
            field_dict["outdated"] = outdated
        if version_metadata is not UNSET:
            field_dict["version_metadata"] = version_metadata

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        task_id = d.pop("task_id")

        doc_id = d.pop("doc_id")

        doc_filename = d.pop("doc_filename")

        doc_path = d.pop("doc_path")

        id = d.pop("id")

        metadata = ExtractResultValidateOutMetadata.from_dict(d.pop("metadata"))

        top_chunks = []
        _top_chunks = d.pop("top_chunks")
        for top_chunks_item_data in _top_chunks:
            top_chunks_item = ExtractTopChunkValidateOut.from_dict(top_chunks_item_data)

            top_chunks.append(top_chunks_item)

        validated_by = d.pop("validated_by", UNSET)

        validated_on: Union[Unset, datetime.datetime] = UNSET
        _validated_on = d.pop("validated_on", UNSET)
        if not isinstance(_validated_on, Unset):
            validated_on = isoparse(_validated_on)

        status = d.pop("status", UNSET)

        found = d.pop("found", UNSET)

        chunk_id = d.pop("chunk_id", UNSET)

        text = d.pop("text", UNSET)

        outdated = d.pop("outdated", UNSET)

        version_metadata: Union[ExtractResultValidateOutVersionMetadata, Unset] = UNSET
        _version_metadata = d.pop("version_metadata", UNSET)
        if not isinstance(_version_metadata, Unset):
            version_metadata = ExtractResultValidateOutVersionMetadata.from_dict(_version_metadata)

        extract_result_validate_out = cls(
            task_id=task_id,
            doc_id=doc_id,
            doc_filename=doc_filename,
            doc_path=doc_path,
            id=id,
            metadata=metadata,
            top_chunks=top_chunks,
            validated_by=validated_by,
            validated_on=validated_on,
            status=status,
            found=found,
            chunk_id=chunk_id,
            text=text,
            outdated=outdated,
            version_metadata=version_metadata,
        )

        extract_result_validate_out.additional_properties = d
        return extract_result_validate_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..models.search_query_out_filters import SearchQueryOutFilters
from ..types import UNSET, Unset

T = TypeVar("T", bound="SearchQueryOut")


@attr.s(auto_attribs=True)
class SearchQueryOut:
    """ Search query schema to output from GET method. """

    user_id: int
    org_id: int
    queried_on: datetime.datetime
    id: int
    folder_ids: Union[Unset, List[int]] = UNSET
    output_fields: Union[Unset, List[str]] = UNSET
    filters: Union[SearchQueryOutFilters, Unset] = UNSET
    keywords: Union[Unset, List[str]] = UNSET
    keyword_op: Union[Unset, None] = UNSET
    keywords_only_query: Union[Unset, bool] = UNSET
    query: Union[Unset, str] = UNSET
    last_version: Union[Unset, bool] = True
    version_ids: Union[Unset, List[int]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        user_id = self.user_id
        org_id = self.org_id
        queried_on = self.queried_on.isoformat()

        id = self.id
        folder_ids: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.folder_ids, Unset):
            folder_ids = self.folder_ids

        output_fields: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.output_fields, Unset):
            output_fields = self.output_fields

        filters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.filters, Unset):
            filters = self.filters.to_dict()

        keywords: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.keywords, Unset):
            keywords = self.keywords

        keyword_op = None

        keywords_only_query = self.keywords_only_query
        query = self.query
        last_version = self.last_version
        version_ids: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.version_ids, Unset):
            version_ids = self.version_ids

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "user_id": user_id,
                "org_id": org_id,
                "queried_on": queried_on,
                "id": id,
            }
        )
        if folder_ids is not UNSET:
            field_dict["folder_ids"] = folder_ids
        if output_fields is not UNSET:
            field_dict["output_fields"] = output_fields
        if filters is not UNSET:
            field_dict["filters"] = filters
        if keywords is not UNSET:
            field_dict["keywords"] = keywords
        if keyword_op is not UNSET:
            field_dict["keyword_op"] = keyword_op
        if keywords_only_query is not UNSET:
            field_dict["keywords_only_query"] = keywords_only_query
        if query is not UNSET:
            field_dict["query"] = query
        if last_version is not UNSET:
            field_dict["last_version"] = last_version
        if version_ids is not UNSET:
            field_dict["version_ids"] = version_ids

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        user_id = d.pop("user_id")

        org_id = d.pop("org_id")

        queried_on = isoparse(d.pop("queried_on"))

        id = d.pop("id")

        folder_ids = cast(List[int], d.pop("folder_ids", UNSET))

        output_fields = cast(List[str], d.pop("output_fields", UNSET))

        filters: Union[SearchQueryOutFilters, Unset] = UNSET
        _filters = d.pop("filters", UNSET)
        if not isinstance(_filters, Unset):
            filters = SearchQueryOutFilters.from_dict(_filters)

        keywords = cast(List[str], d.pop("keywords", UNSET))

        keyword_op = None

        keywords_only_query = d.pop("keywords_only_query", UNSET)

        query = d.pop("query", UNSET)

        last_version = d.pop("last_version", UNSET)

        version_ids = cast(List[int], d.pop("version_ids", UNSET))

        search_query_out = cls(
            user_id=user_id,
            org_id=org_id,
            queried_on=queried_on,
            id=id,
            folder_ids=folder_ids,
            output_fields=output_fields,
            filters=filters,
            keywords=keywords,
            keyword_op=keyword_op,
            keywords_only_query=keywords_only_query,
            query=query,
            last_version=last_version,
            version_ids=version_ids,
        )

        search_query_out.additional_properties = d
        return search_query_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.document_result import DocumentResult
from ..models.search_result_documents_documents_item import SearchResultDocumentsDocumentsItem
from ..types import UNSET, Unset

T = TypeVar("T", bound="SearchResultDocuments")


@attr.s(auto_attribs=True)
class SearchResultDocuments:
    """ Schema for search result documents. """

    query_id: int
    total_documents: int
    documents: Union[List[DocumentResult], List[SearchResultDocumentsDocumentsItem]]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        query_id = self.query_id
        total_documents = self.total_documents
        if isinstance(self.documents, list):
            documents = []
            for documents_item_data in self.documents:
                documents_item = documents_item_data.to_dict()

                documents.append(documents_item)

        else:
            documents = []
            for documents_item_data in self.documents:
                documents_item = documents_item_data.to_dict()

                documents.append(documents_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "query_id": query_id,
                "total_documents": total_documents,
                "documents": documents,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        query_id = d.pop("query_id")

        total_documents = d.pop("total_documents")

        def _parse_documents(data: Any) -> Union[List[DocumentResult], List[SearchResultDocumentsDocumentsItem]]:
            data = None if isinstance(data, Unset) else data
            documents: Union[List[DocumentResult], List[SearchResultDocumentsDocumentsItem]]
            try:
                documents = UNSET
                _documents = data
                for documents_item_data in _documents:
                    documents_item = DocumentResult.from_dict(documents_item_data)

                    documents.append(documents_item)

                return documents
            except:  # noqa: E722
                pass
            documents = UNSET
            _documents = data
            for documents_item_data in _documents:
                documents_item = SearchResultDocumentsDocumentsItem.from_dict(documents_item_data)

                documents.append(documents_item)

            return documents

        documents = _parse_documents(d.pop("documents"))

        search_result_documents = cls(
            query_id=query_id,
            total_documents=total_documents,
            documents=documents,
        )

        search_result_documents.additional_properties = d
        return search_result_documents

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="BackgroundTaskIn")


@attr.s(auto_attribs=True)
class BackgroundTaskIn:
    """ Background task schema for the POST route. """

    name: str
    task_type: str
    total_items: Union[Unset, int] = UNSET
    user_id: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        task_type = self.task_type
        total_items = self.total_items
        user_id = self.user_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "task_type": task_type,
            }
        )
        if total_items is not UNSET:
            field_dict["total_items"] = total_items
        if user_id is not UNSET:
            field_dict["user_id"] = user_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        task_type = d.pop("task_type")

        total_items = d.pop("total_items", UNSET)

        user_id = d.pop("user_id", UNSET)

        background_task_in = cls(
            name=name,
            task_type=task_type,
            total_items=total_items,
            user_id=user_id,
        )

        background_task_in.additional_properties = d
        return background_task_in

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.search_query_string_query import SearchQueryStringQuery
from ...models.search_result_documents import SearchResultDocuments
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    json_body: SearchQueryStringQuery,
    query_id: Union[Unset, int] = UNSET,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Dict[str, Any]:
    url = "{}/api/v1/search/documents/".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "query_id": query_id,
        "limit": limit,
        "offset": offset,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[SearchResultDocuments, None, None, None, None, None]]:
    if response.status_code == 200:
        response_200 = SearchResultDocuments.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 422:
        response_422 = None

        return response_422
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 400:
        response_400 = None

        return response_400
    if response.status_code == 404:
        response_404 = None

        return response_404
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[SearchResultDocuments, None, None, None, None, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: SearchQueryStringQuery,
    query_id: Union[Unset, int] = UNSET,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Response[Union[SearchResultDocuments, None, None, None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        query_id=query_id,
        limit=limit,
        offset=offset,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: SearchQueryStringQuery,
    query_id: Union[Unset, int] = UNSET,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Optional[Union[SearchResultDocuments, None, None, None, None, None]]:
    """Document searching endpoint.

    The route takes as input a query and returns a list of documents,
    ordered by their ranking score.

    The user must have at least read rights on the folders they are searching in.

    If no folder_ids are given, all folders the user has rights on are searched.

    In case the request is another result page of an existing query,
    the query_id parameter must be set to avoid storing the same query several times."""

    return sync_detailed(
        client=client,
        json_body=json_body,
        query_id=query_id,
        limit=limit,
        offset=offset,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: SearchQueryStringQuery,
    query_id: Union[Unset, int] = UNSET,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Response[Union[SearchResultDocuments, None, None, None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        query_id=query_id,
        limit=limit,
        offset=offset,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: SearchQueryStringQuery,
    query_id: Union[Unset, int] = UNSET,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Optional[Union[SearchResultDocuments, None, None, None, None, None]]:
    """Document searching endpoint.

    The route takes as input a query and returns a list of documents,
    ordered by their ranking score.

    The user must have at least read rights on the folders they are searching in.

    If no folder_ids are given, all folders the user has rights on are searched.

    In case the request is another result page of an existing query,
    the query_id parameter must be set to avoid storing the same query several times."""

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            query_id=query_id,
            limit=limit,
            offset=offset,
        )
    ).parsed



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="BlockFromDigester")


@attr.s(auto_attribs=True)
class BlockFromDigester:
    """ Chunk block description """

    page_number: int
    bbox: Union[Unset, List[None]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        page_number = self.page_number
        bbox: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.bbox, Unset):
            bbox = []
            for bbox_item_data in self.bbox:
                bbox_item = None

                bbox.append(bbox_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "page_number": page_number,
            }
        )
        if bbox is not UNSET:
            field_dict["bbox"] = bbox

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        page_number = d.pop("page_number")

        bbox = []
        _bbox = d.pop("bbox", UNSET)
        for bbox_item_data in _bbox or []:
            bbox_item = None

            bbox.append(bbox_item)

        block_from_digester = cls(
            page_number=page_number,
            bbox=bbox,
        )

        block_from_digester.additional_properties = d
        return block_from_digester

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.value_type import ValueType
from ..types import UNSET, Unset

T = TypeVar("T", bound="ExtractValueConfig")


@attr.s(auto_attribs=True)
class ExtractValueConfig:
    """ Value extraction configuration schema for extract models. """

    value_type: ValueType
    value: str
    all_values: bool
    keywords: List[str]
    words_around: List[str]
    keywords_operator: Union[Unset, None] = UNSET
    keywords_scope: Union[Unset, None] = UNSET
    start_page: Union[Unset, int] = UNSET
    end_page: Union[Unset, int] = UNSET
    words_direction: Union[Unset, None] = UNSET
    words_range: Union[Unset, int] = 10
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        value_type = self.value_type.value

        value = self.value
        all_values = self.all_values
        keywords = self.keywords

        words_around = self.words_around

        keywords_operator = None

        keywords_scope = None

        start_page = self.start_page
        end_page = self.end_page
        words_direction = None

        words_range = self.words_range

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "value_type": value_type,
                "value": value,
                "all_values": all_values,
                "keywords": keywords,
                "words_around": words_around,
            }
        )
        if keywords_operator is not UNSET:
            field_dict["keywords_operator"] = keywords_operator
        if keywords_scope is not UNSET:
            field_dict["keywords_scope"] = keywords_scope
        if start_page is not UNSET:
            field_dict["start_page"] = start_page
        if end_page is not UNSET:
            field_dict["end_page"] = end_page
        if words_direction is not UNSET:
            field_dict["words_direction"] = words_direction
        if words_range is not UNSET:
            field_dict["words_range"] = words_range

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        value_type = ValueType(d.pop("value_type"))

        value = d.pop("value")

        all_values = d.pop("all_values")

        keywords = cast(List[str], d.pop("keywords"))

        words_around = cast(List[str], d.pop("words_around"))

        keywords_operator = None

        keywords_scope = None

        start_page = d.pop("start_page", UNSET)

        end_page = d.pop("end_page", UNSET)

        words_direction = None

        words_range = d.pop("words_range", UNSET)

        extract_value_config = cls(
            value_type=value_type,
            value=value,
            all_values=all_values,
            keywords=keywords,
            words_around=words_around,
            keywords_operator=keywords_operator,
            keywords_scope=keywords_scope,
            start_page=start_page,
            end_page=end_page,
            words_direction=words_direction,
            words_range=words_range,
        )

        extract_value_config.additional_properties = d
        return extract_value_config

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/api/v1/folders/{folder_id}/reindex/".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[None, None, None, None]]:
    if response.status_code == 501:
        response_501 = None

        return response_501
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 403:
        response_403 = None

        return response_403
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[None, None, None, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
) -> Response[Union[None, None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
) -> Optional[Union[None, None, None, None]]:
    """Requests the reindexing of a folder.

    If the children parameter is set to true, folder's child hierarchy is also reindexed. If
    set to false or not present, only the specified folder should be reindexed.
    - If the user is basic, they cannot request a folder reindexing.
    - If the user is orgadmin, they can reindex all of their own organization's folders."""

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
) -> Response[Union[None, None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
) -> Optional[Union[None, None, None, None]]:
    """Requests the reindexing of a folder.

    If the children parameter is set to true, folder's child hierarchy is also reindexed. If
    set to false or not present, only the specified folder should be reindexed.
    - If the user is basic, they cannot request a folder reindexing.
    - If the user is orgadmin, they can reindex all of their own organization's folders."""

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="IndexingTaskCreate")


@attr.s(auto_attribs=True)
class IndexingTaskCreate:
    """ Indexing task schema. """

    total_items: Union[Unset, int] = 0
    org_id: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        total_items = self.total_items
        org_id = self.org_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if total_items is not UNSET:
            field_dict["total_items"] = total_items
        if org_id is not UNSET:
            field_dict["org_id"] = org_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        total_items = d.pop("total_items", UNSET)

        org_id = d.pop("org_id", UNSET)

        indexing_task_create = cls(
            total_items=total_items,
            org_id=org_id,
        )

        indexing_task_create.additional_properties = d
        return indexing_task_create

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.extract_top_chunk_validate_out_coordinates import ExtractTopChunkValidateOutCoordinates
from ..models.extract_top_chunk_validate_out_div_idxs import ExtractTopChunkValidateOutDivIdxs
from ..types import UNSET, Unset

T = TypeVar("T", bound="ExtractTopChunkValidateOut")


@attr.s(auto_attribs=True)
class ExtractTopChunkValidateOut:
    """ Top chunk schema in extract result to validate. """

    result_id: int
    rank: int
    chunk_id: str
    page: int
    text: str
    div_idxs: Union[ExtractTopChunkValidateOutDivIdxs, Unset] = UNSET
    coordinates: Union[ExtractTopChunkValidateOutCoordinates, Unset] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        result_id = self.result_id
        rank = self.rank
        chunk_id = self.chunk_id
        page = self.page
        text = self.text
        div_idxs: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.div_idxs, Unset):
            div_idxs = self.div_idxs.to_dict()

        coordinates: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.coordinates, Unset):
            coordinates = self.coordinates.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "result_id": result_id,
                "rank": rank,
                "chunk_id": chunk_id,
                "page": page,
                "text": text,
            }
        )
        if div_idxs is not UNSET:
            field_dict["div_idxs"] = div_idxs
        if coordinates is not UNSET:
            field_dict["coordinates"] = coordinates

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        result_id = d.pop("result_id")

        rank = d.pop("rank")

        chunk_id = d.pop("chunk_id")

        page = d.pop("page")

        text = d.pop("text")

        div_idxs: Union[ExtractTopChunkValidateOutDivIdxs, Unset] = UNSET
        _div_idxs = d.pop("div_idxs", UNSET)
        if not isinstance(_div_idxs, Unset):
            div_idxs = ExtractTopChunkValidateOutDivIdxs.from_dict(_div_idxs)

        coordinates: Union[ExtractTopChunkValidateOutCoordinates, Unset] = UNSET
        _coordinates = d.pop("coordinates", UNSET)
        if not isinstance(_coordinates, Unset):
            coordinates = ExtractTopChunkValidateOutCoordinates.from_dict(_coordinates)

        extract_top_chunk_validate_out = cls(
            result_id=result_id,
            rank=rank,
            chunk_id=chunk_id,
            page=page,
            text=text,
            div_idxs=div_idxs,
            coordinates=coordinates,
        )

        extract_top_chunk_validate_out.additional_properties = d
        return extract_top_chunk_validate_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="ChunkBookmarkCreate")


@attr.s(auto_attribs=True)
class ChunkBookmarkCreate:
    """ Chunk bookmark schema to receive from the POST method. """

    query_id: int
    collection_id: int
    version_id: int
    chunk_id: str
    chunk_text: str
    from_semantic: bool
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        query_id = self.query_id
        collection_id = self.collection_id
        version_id = self.version_id
        chunk_id = self.chunk_id
        chunk_text = self.chunk_text
        from_semantic = self.from_semantic

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "query_id": query_id,
                "collection_id": collection_id,
                "version_id": version_id,
                "chunk_id": chunk_id,
                "chunk_text": chunk_text,
                "from_semantic": from_semantic,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        query_id = d.pop("query_id")

        collection_id = d.pop("collection_id")

        version_id = d.pop("version_id")

        chunk_id = d.pop("chunk_id")

        chunk_text = d.pop("chunk_text")

        from_semantic = d.pop("from_semantic")

        chunk_bookmark_create = cls(
            query_id=query_id,
            collection_id=collection_id,
            version_id=version_id,
            chunk_id=chunk_id,
            chunk_text=chunk_text,
            from_semantic=from_semantic,
        )

        chunk_bookmark_create.additional_properties = d
        return chunk_bookmark_create

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.body_post_file_version_api_v1_files_versions_item_item_id__post import (
    BodyPostFileVersionApiV1FilesVersionsItem_ItemId__Post,
)
from ...models.version import Version
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    item_id: int,
    multipart_data: BodyPostFileVersionApiV1FilesVersionsItem_ItemId__Post,
    idx_task_id: Union[Unset, int] = UNSET,
    incremental: Union[Unset, bool] = False,
) -> Dict[str, Any]:
    url = "{}/api/v1/files/versions/item/{item_id}/".format(client.base_url, item_id=item_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "idx_task_id": idx_task_id,
        "incremental": incremental,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "files": multipart_data.to_dict(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[Version, None, None, None, None, None]]:
    if response.status_code == 201:
        response_201 = Version.from_dict(response.json())

        return response_201
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 400:
        response_400 = None

        return response_400
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 422:
        response_422 = None

        return response_422
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[Version, None, None, None, None, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    item_id: int,
    multipart_data: BodyPostFileVersionApiV1FilesVersionsItem_ItemId__Post,
    idx_task_id: Union[Unset, int] = UNSET,
    incremental: Union[Unset, bool] = False,
) -> Response[Union[Version, None, None, None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        item_id=item_id,
        multipart_data=multipart_data,
        idx_task_id=idx_task_id,
        incremental=incremental,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    item_id: int,
    multipart_data: BodyPostFileVersionApiV1FilesVersionsItem_ItemId__Post,
    idx_task_id: Union[Unset, int] = UNSET,
    incremental: Union[Unset, bool] = False,
) -> Optional[Union[Version, None, None, None, None, None]]:
    """Creates a new version of a file item.<br/>
    When a new version is created, it is automatically marked as the latest one
    and its name and display_name are inherited from the parent file item.<br/>
    If the number of versions of the parent item exceeds the maximum one
    specified in the organization versioning policy, the oldest version is deleted.

    An optional idx_task_id query parameter may be passed to the route,
    which will be saved on the file.

    An incremental query parameter could be passed
    to specify if the task item number should be incremented.

    - If the user is basic, they can only add files in folders they have write rights on.
    - If the user is orgadmin, they can add files in any of their organization's folders."""

    return sync_detailed(
        client=client,
        item_id=item_id,
        multipart_data=multipart_data,
        idx_task_id=idx_task_id,
        incremental=incremental,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    item_id: int,
    multipart_data: BodyPostFileVersionApiV1FilesVersionsItem_ItemId__Post,
    idx_task_id: Union[Unset, int] = UNSET,
    incremental: Union[Unset, bool] = False,
) -> Response[Union[Version, None, None, None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        item_id=item_id,
        multipart_data=multipart_data,
        idx_task_id=idx_task_id,
        incremental=incremental,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    item_id: int,
    multipart_data: BodyPostFileVersionApiV1FilesVersionsItem_ItemId__Post,
    idx_task_id: Union[Unset, int] = UNSET,
    incremental: Union[Unset, bool] = False,
) -> Optional[Union[Version, None, None, None, None, None]]:
    """Creates a new version of a file item.<br/>
    When a new version is created, it is automatically marked as the latest one
    and its name and display_name are inherited from the parent file item.<br/>
    If the number of versions of the parent item exceeds the maximum one
    specified in the organization versioning policy, the oldest version is deleted.

    An optional idx_task_id query parameter may be passed to the route,
    which will be saved on the file.

    An incremental query parameter could be passed
    to specify if the task item number should be incremented.

    - If the user is basic, they can only add files in folders they have write rights on.
    - If the user is orgadmin, they can add files in any of their organization's folders."""

    return (
        await asyncio_detailed(
            client=client,
            item_id=item_id,
            multipart_data=multipart_data,
            idx_task_id=idx_task_id,
            incremental=incremental,
        )
    ).parsed



from typing import Any, Dict, List, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.folder_out import FolderOut
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    org_id: Union[Unset, int] = UNSET,
    path: Union[Unset, str] = UNSET,
    name: Union[Unset, str] = UNSET,
    exact: Union[Unset, bool] = False,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Dict[str, Any]:
    url = "{}/api/v1/folders/".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "org_id": org_id,
        "path": path,
        "name": name,
        "exact": exact,
        "limit": limit,
        "offset": offset,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[List[FolderOut], None, None, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = FolderOut.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[List[FolderOut], None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    org_id: Union[Unset, int] = UNSET,
    path: Union[Unset, str] = UNSET,
    name: Union[Unset, str] = UNSET,
    exact: Union[Unset, bool] = False,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Response[Union[List[FolderOut], None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        org_id=org_id,
        path=path,
        name=name,
        exact=exact,
        limit=limit,
        offset=offset,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    org_id: Union[Unset, int] = UNSET,
    path: Union[Unset, str] = UNSET,
    name: Union[Unset, str] = UNSET,
    exact: Union[Unset, bool] = False,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Optional[Union[List[FolderOut], None, None, HTTPValidationError]]:
    """Gets a page of all folders the user has access to:
    - If the user is basic, they can only access folders they had rights on.
    - If the user is orgadmin, they can access all of their own organization's folders.

    Additionally, search query parameters can be provided. In case 'path' is provided,
    'name' is ignored. An extra parameter 'exact' can be set if the exact folder path or
    name is needed from the folders."""

    return sync_detailed(
        client=client,
        org_id=org_id,
        path=path,
        name=name,
        exact=exact,
        limit=limit,
        offset=offset,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    org_id: Union[Unset, int] = UNSET,
    path: Union[Unset, str] = UNSET,
    name: Union[Unset, str] = UNSET,
    exact: Union[Unset, bool] = False,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Response[Union[List[FolderOut], None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        org_id=org_id,
        path=path,
        name=name,
        exact=exact,
        limit=limit,
        offset=offset,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    org_id: Union[Unset, int] = UNSET,
    path: Union[Unset, str] = UNSET,
    name: Union[Unset, str] = UNSET,
    exact: Union[Unset, bool] = False,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Optional[Union[List[FolderOut], None, None, HTTPValidationError]]:
    """Gets a page of all folders the user has access to:
    - If the user is basic, they can only access folders they had rights on.
    - If the user is orgadmin, they can access all of their own organization's folders.

    Additionally, search query parameters can be provided. In case 'path' is provided,
    'name' is ignored. An extra parameter 'exact' can be set if the exact folder path or
    name is needed from the folders."""

    return (
        await asyncio_detailed(
            client=client,
            org_id=org_id,
            path=path,
            name=name,
            exact=exact,
            limit=limit,
            offset=offset,
        )
    ).parsed



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.doc_count import DocCount
from ...models.http_validation_error import HTTPValidationError
from ...models.source_type import SourceType
from ...types import UNSET, Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    source: SourceType,
    filters: str,
) -> Dict[str, Any]:
    url = "{}/api/v1/extract/tasks/doc_count/".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_source = source.value

    params: Dict[str, Any] = {
        "source": json_source,
        "filters": filters,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[DocCount, None, None, None, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = DocCount.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[DocCount, None, None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    source: SourceType,
    filters: str,
) -> Response[Union[DocCount, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        source=source,
        filters=filters,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    source: SourceType,
    filters: str,
) -> Optional[Union[DocCount, None, None, None, HTTPValidationError]]:
    """Get the number of documents from an extract data source.

    Only orgadmins are allowed to access extract tasks.

    The id of the organization is inferred from the session token.

    If the source is:
    - \"folders\": filters must be a string list of folder ids to get documents from.
    Example: /?filters=1,2,3,4
    - \"metadata\": filters must a be the name of a metadata.

    In the latter case, if the metadata is:
    - binary: the route returns the number of documents for which the value is true.
    - non-binary: the route returns the number of documents for which the value exists."""

    return sync_detailed(
        client=client,
        source=source,
        filters=filters,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    source: SourceType,
    filters: str,
) -> Response[Union[DocCount, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        source=source,
        filters=filters,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    source: SourceType,
    filters: str,
) -> Optional[Union[DocCount, None, None, None, HTTPValidationError]]:
    """Get the number of documents from an extract data source.

    Only orgadmins are allowed to access extract tasks.

    The id of the organization is inferred from the session token.

    If the source is:
    - \"folders\": filters must be a string list of folder ids to get documents from.
    Example: /?filters=1,2,3,4
    - \"metadata\": filters must a be the name of a metadata.

    In the latter case, if the metadata is:
    - binary: the route returns the number of documents for which the value is true.
    - non-binary: the route returns the number of documents for which the value exists."""

    return (
        await asyncio_detailed(
            client=client,
            source=source,
            filters=filters,
        )
    ).parsed



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.group_out import GroupOut
from ..models.timezone import Timezone
from ..models.user_language import UserLanguage
from ..models.user_role import UserRole
from ..models.user_status import UserStatus
from ..types import UNSET, Unset

T = TypeVar("T", bound="UserOut")


@attr.s(auto_attribs=True)
class UserOut:
    """ User schema to output from GET methods. """

    id: int
    org_id: int
    first_name: str
    last_name: str
    email: str
    language: UserLanguage
    timezone: Timezone
    password_updated_on: datetime.datetime
    role: UserRole
    org_contact: bool
    status: UserStatus
    active: bool
    created_on: datetime.datetime
    last_login_on: Union[Unset, datetime.datetime] = UNSET
    groups: Union[Unset, List[GroupOut]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        org_id = self.org_id
        first_name = self.first_name
        last_name = self.last_name
        email = self.email
        language = self.language.value

        timezone = self.timezone.value

        password_updated_on = self.password_updated_on.isoformat()

        role = self.role.value

        org_contact = self.org_contact
        status = self.status.value

        active = self.active
        created_on = self.created_on.isoformat()

        last_login_on: Union[Unset, str] = UNSET
        if not isinstance(self.last_login_on, Unset):
            last_login_on = self.last_login_on.isoformat()

        groups: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.groups, Unset):
            groups = []
            for groups_item_data in self.groups:
                groups_item = groups_item_data.to_dict()

                groups.append(groups_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "org_id": org_id,
                "first_name": first_name,
                "last_name": last_name,
                "email": email,
                "language": language,
                "timezone": timezone,
                "password_updated_on": password_updated_on,
                "role": role,
                "org_contact": org_contact,
                "status": status,
                "active": active,
                "created_on": created_on,
            }
        )
        if last_login_on is not UNSET:
            field_dict["last_login_on"] = last_login_on
        if groups is not UNSET:
            field_dict["groups"] = groups

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        org_id = d.pop("org_id")

        first_name = d.pop("first_name")

        last_name = d.pop("last_name")

        email = d.pop("email")

        language = UserLanguage(d.pop("language"))

        timezone = Timezone(d.pop("timezone"))

        password_updated_on = isoparse(d.pop("password_updated_on"))

        role = UserRole(d.pop("role"))

        org_contact = d.pop("org_contact")

        status = UserStatus(d.pop("status"))

        active = d.pop("active")

        created_on = isoparse(d.pop("created_on"))

        last_login_on: Union[Unset, datetime.datetime] = UNSET
        _last_login_on = d.pop("last_login_on", UNSET)
        if not isinstance(_last_login_on, Unset):
            last_login_on = isoparse(_last_login_on)

        groups = []
        _groups = d.pop("groups", UNSET)
        for groups_item_data in _groups or []:
            groups_item = GroupOut.from_dict(groups_item_data)

            groups.append(groups_item)

        user_out = cls(
            id=id,
            org_id=org_id,
            first_name=first_name,
            last_name=last_name,
            email=email,
            language=language,
            timezone=timezone,
            password_updated_on=password_updated_on,
            role=role,
            org_contact=org_contact,
            status=status,
            active=active,
            created_on=created_on,
            last_login_on=last_login_on,
            groups=groups,
        )

        user_out.additional_properties = d
        return user_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar

import attr
from dateutil.parser import isoparse

from ..models.event_out_args import EventOutArgs

T = TypeVar("T", bound="EventOut")


@attr.s(auto_attribs=True)
class EventOut:
    """ Event schema to output from GET methods. """

    user_name: str
    timestamp: datetime.datetime
    code: int
    desc: str
    args: EventOutArgs
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        user_name = self.user_name
        timestamp = self.timestamp.isoformat()

        code = self.code
        desc = self.desc
        args = self.args.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "user_name": user_name,
                "timestamp": timestamp,
                "code": code,
                "desc": desc,
                "args": args,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        user_name = d.pop("user_name")

        timestamp = isoparse(d.pop("timestamp"))

        code = d.pop("code")

        desc = d.pop("desc")

        args = EventOutArgs.from_dict(d.pop("args"))

        event_out = cls(
            user_name=user_name,
            timestamp=timestamp,
            code=code,
            desc=desc,
            args=args,
        )

        event_out.additional_properties = d
        return event_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ExtractType(str, Enum):
    PARAGRAPH = "paragraph"
    VALUE = "value"
    QUESTION = "question"
    QUESTIONNAIRE = "questionnaire"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.doc_source import DocSource
from ..models.extract_type import ExtractType
from ..types import UNSET, Unset

T = TypeVar("T", bound="Task")


@attr.s(auto_attribs=True)
class Task:
    """ Task schema. """

    type: ExtractType
    name: str
    doc_source: DocSource
    per_folder: Union[Unset, bool] = False
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        name = self.name
        doc_source = self.doc_source.to_dict()

        per_folder = self.per_folder

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
                "name": name,
                "doc_source": doc_source,
            }
        )
        if per_folder is not UNSET:
            field_dict["per_folder"] = per_folder

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = ExtractType(d.pop("type"))

        name = d.pop("name")

        doc_source = DocSource.from_dict(d.pop("doc_source"))

        per_folder = d.pop("per_folder", UNSET)

        task = cls(
            type=type,
            name=name,
            doc_source=doc_source,
            per_folder=per_folder,
        )

        task.additional_properties = d
        return task

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.metadata_out import MetadataOut
from ..types import UNSET, Unset

T = TypeVar("T", bound="MetadataDisplayOut")


@attr.s(auto_attribs=True)
class MetadataDisplayOut:
    """ Schema representing metadata display options to output in GET method. """

    primary_filters: Union[Unset, List[MetadataOut]] = UNSET
    secondary_filters: Union[Unset, List[MetadataOut]] = UNSET
    chunks_results: Union[Unset, List[MetadataOut]] = UNSET
    sorting_metadata: Union[Unset, List[MetadataOut]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        primary_filters: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.primary_filters, Unset):
            primary_filters = []
            for primary_filters_item_data in self.primary_filters:
                primary_filters_item = primary_filters_item_data.to_dict()

                primary_filters.append(primary_filters_item)

        secondary_filters: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.secondary_filters, Unset):
            secondary_filters = []
            for secondary_filters_item_data in self.secondary_filters:
                secondary_filters_item = secondary_filters_item_data.to_dict()

                secondary_filters.append(secondary_filters_item)

        chunks_results: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.chunks_results, Unset):
            chunks_results = []
            for chunks_results_item_data in self.chunks_results:
                chunks_results_item = chunks_results_item_data.to_dict()

                chunks_results.append(chunks_results_item)

        sorting_metadata: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.sorting_metadata, Unset):
            sorting_metadata = []
            for sorting_metadata_item_data in self.sorting_metadata:
                sorting_metadata_item = sorting_metadata_item_data.to_dict()

                sorting_metadata.append(sorting_metadata_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if primary_filters is not UNSET:
            field_dict["primary_filters"] = primary_filters
        if secondary_filters is not UNSET:
            field_dict["secondary_filters"] = secondary_filters
        if chunks_results is not UNSET:
            field_dict["chunks_results"] = chunks_results
        if sorting_metadata is not UNSET:
            field_dict["sorting_metadata"] = sorting_metadata

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        primary_filters = []
        _primary_filters = d.pop("primary_filters", UNSET)
        for primary_filters_item_data in _primary_filters or []:
            primary_filters_item = MetadataOut.from_dict(primary_filters_item_data)

            primary_filters.append(primary_filters_item)

        secondary_filters = []
        _secondary_filters = d.pop("secondary_filters", UNSET)
        for secondary_filters_item_data in _secondary_filters or []:
            secondary_filters_item = MetadataOut.from_dict(secondary_filters_item_data)

            secondary_filters.append(secondary_filters_item)

        chunks_results = []
        _chunks_results = d.pop("chunks_results", UNSET)
        for chunks_results_item_data in _chunks_results or []:
            chunks_results_item = MetadataOut.from_dict(chunks_results_item_data)

            chunks_results.append(chunks_results_item)

        sorting_metadata = []
        _sorting_metadata = d.pop("sorting_metadata", UNSET)
        for sorting_metadata_item_data in _sorting_metadata or []:
            sorting_metadata_item = MetadataOut.from_dict(sorting_metadata_item_data)

            sorting_metadata.append(sorting_metadata_item)

        metadata_display_out = cls(
            primary_filters=primary_filters,
            secondary_filters=secondary_filters,
            chunks_results=chunks_results,
            sorting_metadata=sorting_metadata,
        )

        metadata_display_out.additional_properties = d
        return metadata_display_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, cast

import attr

T = TypeVar("T", bound="SourceFilters")


@attr.s(auto_attribs=True)
class SourceFilters:
    """ Source filters schema. """

    metadata_name: str
    folder_ids: List[int]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        metadata_name = self.metadata_name
        folder_ids = self.folder_ids

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "metadata_name": metadata_name,
                "folder_ids": folder_ids,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        metadata_name = d.pop("metadata_name")

        folder_ids = cast(List[int], d.pop("folder_ids"))

        source_filters = cls(
            metadata_name=metadata_name,
            folder_ids=folder_ids,
        )

        source_filters.additional_properties = d
        return source_filters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar

import attr
from dateutil.parser import isoparse

from ..models.extract_top_chunk import ExtractTopChunk

T = TypeVar("T", bound="ExtractPredictionIn")


@attr.s(auto_attribs=True)
class ExtractPredictionIn:
    """ Schema for POST /predictions. """

    batch_processed_at: datetime.datetime
    top_chunks: List[ExtractTopChunk]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        batch_processed_at = self.batch_processed_at.isoformat()

        top_chunks = []
        for top_chunks_item_data in self.top_chunks:
            top_chunks_item = top_chunks_item_data.to_dict()

            top_chunks.append(top_chunks_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "batch_processed_at": batch_processed_at,
                "top_chunks": top_chunks,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        batch_processed_at = isoparse(d.pop("batch_processed_at"))

        top_chunks = []
        _top_chunks = d.pop("top_chunks")
        for top_chunks_item_data in _top_chunks:
            top_chunks_item = ExtractTopChunk.from_dict(top_chunks_item_data)

            top_chunks.append(top_chunks_item)

        extract_prediction_in = cls(
            batch_processed_at=batch_processed_at,
            top_chunks=top_chunks,
        )

        extract_prediction_in.additional_properties = d
        return extract_prediction_in

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.folder_right import FolderRight

T = TypeVar("T", bound="GroupFolderRights")


@attr.s(auto_attribs=True)
class GroupFolderRights:
    """ Group's folders rights. """

    rights: List[FolderRight]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        rights = []
        for rights_item_data in self.rights:
            rights_item = rights_item_data.to_dict()

            rights.append(rights_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "rights": rights,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        rights = []
        _rights = d.pop("rights")
        for rights_item_data in _rights:
            rights_item = FolderRight.from_dict(rights_item_data)

            rights.append(rights_item)

        group_folder_rights = cls(
            rights=rights,
        )

        group_folder_rights.additional_properties = d
        return group_folder_rights

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.chunk_bookmark_out import ChunkBookmarkOut

T = TypeVar("T", bound="ChunkBookmarkResult")


@attr.s(auto_attribs=True)
class ChunkBookmarkResult:
    """ Chunk bookmark result schema. """

    chunks: List[ChunkBookmarkOut]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        chunks = []
        for chunks_item_data in self.chunks:
            chunks_item = chunks_item_data.to_dict()

            chunks.append(chunks_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "chunks": chunks,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        chunks = []
        _chunks = d.pop("chunks")
        for chunks_item_data in _chunks:
            chunks_item = ChunkBookmarkOut.from_dict(chunks_item_data)

            chunks.append(chunks_item)

        chunk_bookmark_result = cls(
            chunks=chunks,
        )

        chunk_bookmark_result.additional_properties = d
        return chunk_bookmark_result

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="ArchivesOut")


@attr.s(auto_attribs=True)
class ArchivesOut:
    """ Archives schema for the POST route. """

    archive_size: int
    uncompress_bkg_task_id: int
    indexing_bkg_task_id: int
    indexing_report_id: int
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        archive_size = self.archive_size
        uncompress_bkg_task_id = self.uncompress_bkg_task_id
        indexing_bkg_task_id = self.indexing_bkg_task_id
        indexing_report_id = self.indexing_report_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "archive_size": archive_size,
                "uncompress_bkg_task_id": uncompress_bkg_task_id,
                "indexing_bkg_task_id": indexing_bkg_task_id,
                "indexing_report_id": indexing_report_id,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        archive_size = d.pop("archive_size")

        uncompress_bkg_task_id = d.pop("uncompress_bkg_task_id")

        indexing_bkg_task_id = d.pop("indexing_bkg_task_id")

        indexing_report_id = d.pop("indexing_report_id")

        archives_out = cls(
            archive_size=archive_size,
            uncompress_bkg_task_id=uncompress_bkg_task_id,
            indexing_bkg_task_id=indexing_bkg_task_id,
            indexing_report_id=indexing_report_id,
        )

        archives_out.additional_properties = d
        return archives_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="BodyPostUserLoginApiV1Login_Post")


@attr.s(auto_attribs=True)
class BodyPostUserLoginApiV1Login_Post:
    """  """

    username: str
    password: str
    totp: Union[Unset, str] = UNSET
    new_password: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        username = self.username
        password = self.password
        totp = self.totp
        new_password = self.new_password

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "username": username,
                "password": password,
            }
        )
        if totp is not UNSET:
            field_dict["totp"] = totp
        if new_password is not UNSET:
            field_dict["new_password"] = new_password

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        username = d.pop("username")

        password = d.pop("password")

        totp = d.pop("totp", UNSET)

        new_password = d.pop("new_password", UNSET)

        body_post_user_login_api_v1_login_post = cls(
            username=username,
            password=password,
            totp=totp,
            new_password=new_password,
        )

        body_post_user_login_api_v1_login_post.additional_properties = d
        return body_post_user_login_api_v1_login_post

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.search_query_string_query import SearchQueryStringQuery
from ...models.search_result_chunks import SearchResultChunks
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    json_body: SearchQueryStringQuery,
    query_id: Union[Unset, int] = UNSET,
    skip_autosuggest: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Dict[str, Any]:
    url = "{}/api/v1/search/chunks/".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "query_id": query_id,
        "skip_autosuggest": skip_autosuggest,
        "limit": limit,
        "offset": offset,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[SearchResultChunks, None, None, None, None, None]]:
    if response.status_code == 200:
        response_200 = SearchResultChunks.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 422:
        response_422 = None

        return response_422
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 400:
        response_400 = None

        return response_400
    if response.status_code == 404:
        response_404 = None

        return response_404
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[SearchResultChunks, None, None, None, None, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: SearchQueryStringQuery,
    query_id: Union[Unset, int] = UNSET,
    skip_autosuggest: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Response[Union[SearchResultChunks, None, None, None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        query_id=query_id,
        skip_autosuggest=skip_autosuggest,
        limit=limit,
        offset=offset,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: SearchQueryStringQuery,
    query_id: Union[Unset, int] = UNSET,
    skip_autosuggest: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Optional[Union[SearchResultChunks, None, None, None, None, None]]:
    """Chunk searching endpoint.

    The route takes as input a query and returns a list of chunks ordered
    by their ranking score.

    The user must have at least read rights on the folders they are searching in.

    If no folder_ids are given, all folders the user has rights on are searched.

    Queries longer than 255 characters are truncated.

    In case the request is another result page of an existing query,
    the query_id parameter must be set to avoid storing the same query several times."""

    return sync_detailed(
        client=client,
        json_body=json_body,
        query_id=query_id,
        skip_autosuggest=skip_autosuggest,
        limit=limit,
        offset=offset,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: SearchQueryStringQuery,
    query_id: Union[Unset, int] = UNSET,
    skip_autosuggest: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Response[Union[SearchResultChunks, None, None, None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        query_id=query_id,
        skip_autosuggest=skip_autosuggest,
        limit=limit,
        offset=offset,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: SearchQueryStringQuery,
    query_id: Union[Unset, int] = UNSET,
    skip_autosuggest: Union[Unset, bool] = UNSET,
    limit: Union[Unset, int] = 100,
    offset: Union[Unset, int] = 0,
) -> Optional[Union[SearchResultChunks, None, None, None, None, None]]:
    """Chunk searching endpoint.

    The route takes as input a query and returns a list of chunks ordered
    by their ranking score.

    The user must have at least read rights on the folders they are searching in.

    If no folder_ids are given, all folders the user has rights on are searched.

    Queries longer than 255 characters are truncated.

    In case the request is another result page of an existing query,
    the query_id parameter must be set to avoid storing the same query several times."""

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            query_id=query_id,
            skip_autosuggest=skip_autosuggest,
            limit=limit,
            offset=offset,
        )
    ).parsed



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.file_item_out import FileItemOut
from ..models.folder_out import FolderOut

T = TypeVar("T", bound="ContentContentOut")


@attr.s(auto_attribs=True)
class ContentContentOut:
    """ Content schema to output from GET method. """

    folders: List[FolderOut]
    files: List[FileItemOut]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        folders = []
        for folders_item_data in self.folders:
            folders_item = folders_item_data.to_dict()

            folders.append(folders_item)

        files = []
        for files_item_data in self.files:
            files_item = files_item_data.to_dict()

            files.append(files_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "folders": folders,
                "files": files,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        folders = []
        _folders = d.pop("folders")
        for folders_item_data in _folders:
            folders_item = FolderOut.from_dict(folders_item_data)

            folders.append(folders_item)

        files = []
        _files = d.pop("files")
        for files_item_data in _files:
            files_item = FileItemOut.from_dict(files_item_data)

            files.append(files_item)

        content_content_out = cls(
            folders=folders,
            files=files,
        )

        content_content_out.additional_properties = d
        return content_content_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.metadata_source import MetadataSource
from ..models.metadata_type import MetadataType
from ..types import UNSET, Unset

T = TypeVar("T", bound="MetadataOut")


@attr.s(auto_attribs=True)
class MetadataOut:
    """ Metadata schema to output from GET methods. """

    name: str
    org_id: int
    value_type: MetadataType
    n_queries: int
    primary_filter: bool
    secondary_filter: bool
    chunks_results: bool
    sorting_metadata: bool
    id: int
    source: MetadataSource
    sample: Union[Unset, None] = UNSET
    nb_distinct_values: Union[Unset, int] = 0
    max_values: Union[Unset, int] = 20
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        org_id = self.org_id
        value_type = self.value_type.value

        n_queries = self.n_queries
        primary_filter = self.primary_filter
        secondary_filter = self.secondary_filter
        chunks_results = self.chunks_results
        sorting_metadata = self.sorting_metadata
        id = self.id
        source = self.source.value

        sample = None

        nb_distinct_values = self.nb_distinct_values
        max_values = self.max_values

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "org_id": org_id,
                "value_type": value_type,
                "n_queries": n_queries,
                "primary_filter": primary_filter,
                "secondary_filter": secondary_filter,
                "chunks_results": chunks_results,
                "sorting_metadata": sorting_metadata,
                "id": id,
                "source": source,
            }
        )
        if sample is not UNSET:
            field_dict["sample"] = sample
        if nb_distinct_values is not UNSET:
            field_dict["nb_distinct_values"] = nb_distinct_values
        if max_values is not UNSET:
            field_dict["max_values"] = max_values

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        org_id = d.pop("org_id")

        value_type = MetadataType(d.pop("value_type"))

        n_queries = d.pop("n_queries")

        primary_filter = d.pop("primary_filter")

        secondary_filter = d.pop("secondary_filter")

        chunks_results = d.pop("chunks_results")

        sorting_metadata = d.pop("sorting_metadata")

        id = d.pop("id")

        source = MetadataSource(d.pop("source"))

        sample = None

        nb_distinct_values = d.pop("nb_distinct_values", UNSET)

        max_values = d.pop("max_values", UNSET)

        metadata_out = cls(
            name=name,
            org_id=org_id,
            value_type=value_type,
            n_queries=n_queries,
            primary_filter=primary_filter,
            secondary_filter=secondary_filter,
            chunks_results=chunks_results,
            sorting_metadata=sorting_metadata,
            id=id,
            source=source,
            sample=sample,
            nb_distinct_values=nb_distinct_values,
            max_values=max_values,
        )

        metadata_out.additional_properties = d
        return metadata_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar

import attr
from dateutil.parser import isoparse

T = TypeVar("T", bound="ChunkCollectionOut")


@attr.s(auto_attribs=True)
class ChunkCollectionOut:
    """ Chunk collection schema to output from the endpoints. """

    id: int
    user_id: int
    name: str
    created_on: datetime.datetime
    updated_on: datetime.datetime
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        user_id = self.user_id
        name = self.name
        created_on = self.created_on.isoformat()

        updated_on = self.updated_on.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "user_id": user_id,
                "name": name,
                "created_on": created_on,
                "updated_on": updated_on,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        user_id = d.pop("user_id")

        name = d.pop("name")

        created_on = isoparse(d.pop("created_on"))

        updated_on = isoparse(d.pop("updated_on"))

        chunk_collection_out = cls(
            id=id,
            user_id=user_id,
            name=name,
            created_on=created_on,
            updated_on=updated_on,
        )

        chunk_collection_out.additional_properties = d
        return chunk_collection_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="ExtractResultValidateIn")


@attr.s(auto_attribs=True)
class ExtractResultValidateIn:
    """ Extract result schema for validate input. """

    validated_rank: int
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        validated_rank = self.validated_rank

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "validated_rank": validated_rank,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        validated_rank = d.pop("validated_rank")

        extract_result_validate_in = cls(
            validated_rank=validated_rank,
        )

        extract_result_validate_in.additional_properties = d
        return extract_result_validate_in

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="ReportOutput")


@attr.s(auto_attribs=True)
class ReportOutput:
    """ Report schema to output from GET methods. """

    name: str
    expires_on: datetime.datetime
    id: int
    user_id: int
    created_on: datetime.datetime
    bkgd_task_id: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        expires_on = self.expires_on.isoformat()

        id = self.id
        user_id = self.user_id
        created_on = self.created_on.isoformat()

        bkgd_task_id = self.bkgd_task_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "expires_on": expires_on,
                "id": id,
                "user_id": user_id,
                "created_on": created_on,
            }
        )
        if bkgd_task_id is not UNSET:
            field_dict["bkgd_task_id"] = bkgd_task_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        expires_on = isoparse(d.pop("expires_on"))

        id = d.pop("id")

        user_id = d.pop("user_id")

        created_on = isoparse(d.pop("created_on"))

        bkgd_task_id = d.pop("bkgd_task_id", UNSET)

        report_output = cls(
            name=name,
            expires_on=expires_on,
            id=id,
            user_id=user_id,
            created_on=created_on,
            bkgd_task_id=bkgd_task_id,
        )

        report_output.additional_properties = d
        return report_output

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class TaskStatus(str, Enum):
    PENDING = "pending"
    RUNNING = "running"
    ERROR = "error"
    DONE = "done"
    CANCELED = "canceled"
    WAIT_FOR_VALIDATION = "wait_for_validation"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.extract_task_create import ExtractTaskCreate
from ...models.extract_task_out import ExtractTaskOut
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    json_body: ExtractTaskCreate,
    model_id: Union[Unset, int] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/extract/tasks/".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "model_id": model_id,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[ExtractTaskOut, None, None, None, None, None, HTTPValidationError]]:
    if response.status_code == 201:
        response_201 = ExtractTaskOut.from_dict(response.json())

        return response_201
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 409:
        response_409 = None

        return response_409
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 400:
        response_400 = None

        return response_400
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[ExtractTaskOut, None, None, None, None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: ExtractTaskCreate,
    model_id: Union[Unset, int] = UNSET,
) -> Response[Union[ExtractTaskOut, None, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        model_id=model_id,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: ExtractTaskCreate,
    model_id: Union[Unset, int] = UNSET,
) -> Optional[Union[ExtractTaskOut, None, None, None, None, None, HTTPValidationError]]:
    """Create and run an extract task.

    Only orgadmins are allowed to create and run extract tasks.
    The id of the organization is inferred from the session token.

    Please note that if it's a value extract, the regex must be valid
    (see dedicated endpoint).

    If model id is passed in the parameters, the task is created from the models.
    Otherwise, the model to be created must be passed in the body."""

    return sync_detailed(
        client=client,
        json_body=json_body,
        model_id=model_id,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: ExtractTaskCreate,
    model_id: Union[Unset, int] = UNSET,
) -> Response[Union[ExtractTaskOut, None, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        model_id=model_id,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: ExtractTaskCreate,
    model_id: Union[Unset, int] = UNSET,
) -> Optional[Union[ExtractTaskOut, None, None, None, None, None, HTTPValidationError]]:
    """Create and run an extract task.

    Only orgadmins are allowed to create and run extract tasks.
    The id of the organization is inferred from the session token.

    Please note that if it's a value extract, the regex must be valid
    (see dedicated endpoint).

    If model id is passed in the parameters, the task is created from the models.
    Otherwise, the model to be created must be passed in the body."""

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            model_id=model_id,
        )
    ).parsed
